import { isNumber } from '@/utils/convert'

const state = {
  newMessage: null,
  newInfo: null,
  message: {
    todo: 0,
    done: 0
  },
  system: {
    'systemCode': 0
  }
}

const mutations = {
  UPDATE_MESSAGE_COUNT: (state, data) => {
    state.message.todo = data.noticeNCount
    state.message.done = data.noticeYCount
  },
  UPDATE_SYSTEM_COUNT: (state, data) => {
    for (const key in data) {
      state.system[key] = data[key]
    }
  },
  UPDATE_MESSAGE: (state, message) => {
    if (message.recordType === 1) {
      state.newInfo = message
    } else {
      state.newMessage = message
    }
  },
  UPDATE_TODO: (state, delta, systemCode) => {
    state.message.todo += delta
    if (!isNumber(state.system[systemCode])) {
      state.system[systemCode] = 0
    }
    state.system[systemCode] += delta
  },
  UPDATE_DONE: (state, delta) => {
    state.message.done += delta
  }
}

const actions = {
  setMessgeCount({ commit }, data) {
    commit('UPDATE_MESSAGE_COUNT', data)
  },
  setSystemCount({ commit }, data) {
    commit('UPDATE_SYSTEM_COUNT', data)
  },
  addNewMessage({ commit }, message) {
    commit('UPDATE_MESSAGE', message)

    if (message.recordType !== 1) {
      commit('UPDATE_TODO', 1, message.createOrgCode)
    }
  },
  readMessage({ commit }, systemCode) {
    commit('UPDATE_TODO', -1, systemCode)
    commit('UPDATE_DONE', 1)
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
