export function toMoney(num) {
  if (num === null || num === undefined) {
    return 0.00
  }
  if (num != null && num.length > 0) {
    try {
      num = parseFloat(num).toFixed(2)
      num = parseFloat(num)
      num = num.toLocaleString()
      return num
    } catch (e) {
      return num
    }
  }
  return num
}

// 空数组 空字符串
export function isNull(str) {
  if (str === null || str === undefined || str.length === 0) {
    return true
  }
  return false
}

export function isNumber(obj) {
  return typeof obj === 'number' && isFinite(obj)
}

// typeof {a: 'a', b: 'b'} // object
// typeof Promise.resolve() // object
// typeof new Date() // object
// typeof [1, 2, 3] // object
export function isObject(obj) {
  return obj !== null && typeof obj === 'object'
}

export function isPlainObject(obj) {
  return Object.prototype.toString.call(obj) === '[object Object]'
}

// Object.keys: 只能遍历可枚举属性
// Object.getOwnPropertyNames: 可枚举和不可枚举，无法获取到用Symbol表示的属性
// Reflect.ownKeys: 可枚举和不可枚举和Symbol
export function isEmptyObj(obj) {
  return isObject(obj) && Object.keys(obj).length === 0
}

export function isArray(obj) {
  if (Array.isArray) {
    return Array.isArray(obj)
  } else {
    return Object.prototype.toString.call(obj) === '[object Array]'
  }
}

// 上传文件格式（文件名字）只能是数字字母下划线空格
export function Regular(str) {
  if (!/^[^`!！@#$%^&*.<>]*$/.test(str)) {
    return true
  }
  return false
}
// 获取当前时间，按一定格式
export function getNowDateFormat(seperator) {
  var date = new Date()
  var seperator1 = seperator || '-'
  var year = date.getFullYear()
  var month = date.getMonth() + 1
  var strDate = date.getDate()
  if (month >= 1 && month <= 9) {
    month = '0' + month
  }
  if (strDate >= 0 && strDate <= 9) {
    strDate = '0' + strDate
  }
  var currentdate = year + seperator1 + month + seperator1 + strDate
  return currentdate
}
// 千位分隔符
export function milliFormat(num) {
  let s = ''
  s = num.toString()
  // if(/[^0-9\.]/.test(s)) return "invalid value";
  s = s.replace(/^(\d*)$/, '$1.')
  s = (s + '00').replace(/(\d*\.\d\d)\d*/, '$1')
  s = s.replace('.', ',')
  var re = /(\d)(\d{3},)/
  while (re.test(s)) {
    s = s.replace(re, '$1,$2')
  }
  s = s.replace(/,(\d\d)$/, '.$1')
  return s.replace(/^\./, '0.')
}
/**
 * 下载文件方法
 * 将调用接口返回的byte数据构造成Blob对象，在document上创建a标签并模拟点击，下载文件，最后删除创建的元素
 * @param {*} filename 文件名
 */
export function downloadFileInDocument(filename, data) {
  const blob = new Blob([data], { type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' })
  if ('download' in document.createElement('a')) {
    const elink = document.createElement('a')
    elink.download = filename
    elink.style.display = 'none'
    elink.href = URL.createObjectURL(blob)
    document.body.appendChild(elink)
    elink.click()
    URL.revokeObjectURL(elink.href) // 释放URL 对象
    document.body.removeChild(elink)
  }
}
export function distinct(arr) {
  const newArr = []
  for (let i = 0; i < arr.length; i++) {
    if (!newArr.includes(arr[i])) {
      newArr.push(arr[i])
    }
  }
  return newArr
}

export function formatDictData(data, code) {
  if (code !== null && code !== undefined && data !== null && data !== undefined) {
    for (let i = 0; i < data.length; i++) {
      if (data[i].id === code) {
        return data[i].label
      }
    }
  }
  return ''
}

export function hasValidRecords(res) {
  return isObject(res.data) && isArray(res.data.records) && res.data.records.length > 0
}
